//==============================================================================
//   FILE : MAIN.C
//
//   DESC : This module performs a demo of PCnet-ISA Ethernet Controller by
//			performing an external loopback using a loopback plug.
//
// TARGET : 16bit Real Mode x86
//
//  TOOLS : Microsoft (R) C/C++ Optimizing Compiler Version 8.00c
//
//                $Revision: 1.0 $
//              $Name: dougp$
//              $Date: 1998/24/12 12:38:33 $
//            $Author: Chipf $
//     
//------------------------------------------------------------------------------
//  Copyright 1997 Advanced Micro Devices, Inc.                                
//                                                                             
//  This software is the property of Advanced Micro Devices, Inc  (AMD)  which 
//  specifically  grants the user the right to modify, use and distribute this 
//  software provided this notice is not removed or altered.  All other rights 
//  are reserved by AMD.                                                       
//                                                                             
//  AMD MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH REGARD TO THIS 
//  SOFTWARE.  IN NO EVENT SHALL AMD BE LIABLE FOR INCIDENTAL OR CONSEQUENTIAL 
//  DAMAGES IN CONNECTION WITH OR ARISING FROM THE FURNISHING, PERFORMANCE, OR 
//  USE OF THIS SOFTWARE.                                                      
//                                                                             
//  So that all may benefit from your experience, please report  any  problems 
//  or suggestions about this software back to AMD.  Please include your name, 
//  company,  telephone number,  AMD product requiring support and question or 
//  problem encountered.                                                       
//                                                                             
//  Advanced Micro Devices, Inc.       Worldwide support and contact           
//  Logic Products Division            information available at:               
//  Systems Engineering                                                        
//  5204 E. Ben White Blvd.     http://www.amd.com/html/support/techsup.html   
//  Austin, TX 78741                                                           
// =============================================================================

#include <stdio.h>        
#include <stdlib.h>
#include <conio.h>

#include "stdincs.h"
#include "am186cc.h"
#include "pcndrv.h"
#include "led.h"

void echo_packet(struct EPACKET *);
void demo_desc(void);
int  ip_esrm(void);

/*
**
**  This is a very simple test for the ethernet on the 186CC router
**  platform.
**
**  This code will wake up the PCnet ISA using the PnP wake up key,
**  and then run the "SENDER" application to test the 10BaseT ethernet
**  interface, and the PCnetISA bus mastering access to the "shared SRAM".
**
**  For this version of the program, I will choose to put SRAM at
**	80000h, and modify UMCS to move start of flash to C0000h.  THis is
**  because E86MON puts it's stack at the top of DRAM at 7ffffh, and moving
**	DRAM down would crash E86MON.
**  Note that if this code is saved in Flash by an E86MON download, it will
**  be saved at 80000h.  When E86MON runs it, it moves the code to DRAM first.
**  Then the code will make the lower part of Flash not available.  So
**  a reset must be pressed after running the code to regain access to the
**  lower part of Flash.
**
*/


#define TX_SIZE 64
#define MAX_DATA 1456
#define CPU_speed 40  // 40 mhz


typedef struct IP_ADDRESS
{
	BYTE	a[4];
} IPA;

// rfc792
struct ICMP_HEADER      	// 8 bytes
{
	BYTE	type;
	BYTE	code;
	WORD	checksum;
	WORD	identifier;
	WORD	seqn;
};

// rfc791
struct IP_HEADER         	// 20 bytes
{
	BYTE	VI;
	BYTE	TOS;
	WORD	length;
	WORD	identification;
	WORD	frag_offset;
	BYTE	ttl;
	BYTE	protocol;
	WORD	checksum;
	IPA		source;
	IPA		dest;
};


struct ENET_HEADER 			// 14 bytes
{
	BYTE	dest[6];		
	BYTE	source[6];		
	WORD	type;
};

// rfc894
struct EPACKET 
{
	struct ENET_HEADER	enh;      //14
	struct IP_HEADER	iph;      //20     = 44 bytes of header
	struct ICMP_HEADER	ich;      //8
	BYTE    data[MAX_DATA];       //1456   = 1500
};
// ok, so this isn't the max ethernet size, but we're only off by a few

//char tbuffer[PCN_MAX_RX_SIZE];
BYTE rbuffer[PCN_MAX_RX_SIZE];

unsigned int count1 = 0x0;		// number of packets received
unsigned int count2 = 0;		// secondary count

struct EPACKET packet;

IPA my_ip_address = {163,181,222,131};		// IP addresses are assigned but not used
IPA their_ip_address = {163,181,222,132};   // in this version of the driver


void InitPacket();
void InitBoard();
void PrintLCD( char * string );

//------------------------------------------------------------------------------
// FUNC   : main()
//
// DESC   : Demonstrates use of ethernet driver for PCnet_ISA ethernet controller
//
//			This program demonstrates an ethernet loopback using the external
//			loopback mode in 10BASE_T MAU mode.  A user interface allows
//          the transmission of an ICMP echo request packet which will be looped
//			back to the ethernet controller and generate another echo request.
//			This will repeat until the user hits 's' to stop or 'q' to quit
//			the program.
//
//  NOTE  : Be sure to view the readme.doc fil for proper setup of this demo.
// ----------------------------------------------------------------------------

void main()
{

PcnInit_s 	ppcnInit;
int		stat;
int		i;
int		r,r1,t,t1;		// seperate led counters for receive and transmit
int		rxlen;			// length of a received packet
int		txlen;			// size of packets to send
int		sending;	    // a flag saying if we are sending (set by a kbhit)
int		reply_recvd;	// flag saying a reply was receive for our request
int		noack;			// flag saying not to wait for replies
struct EPACKET *pptr;

int      decimal = -1;   // keep track of decimal point position
int      user_input= 0;    // stores user time entered in microseconds
unsigned int      refresh_constant;  // integer constant calculated
int 	 input= 0;			// single digit

	demo_desc();		// print prompt to start demo
	
	PostLEDs(0xff);
	PrintLCD("Main");   // output message to LCD on TEST INTERFACE PORT

	InitBoard(refresh_constant);		// configure the hardware before doing anything else
	PostLEDs(0xfe);
	PrintLCD("InitBoard done");
	                           
	printf("186CC Router Platform ethernet test: Sender\n");
	printf("Type a g to go, s to stop, U for unacknowledged send, q to quit.\n");
	ppcnInit.ioport = 0x200;
	ppcnInit.useBurned = 0;		// with no EEPROM, there is no burned in address.
								// so use the fake one I create.								

/*
**This application will create ICMP echo request packets and send them
** out the ethernet port.  There is no protocol layering.  The next sent
** field is updated.
** eventually, this application will also listen for responses.
** This app also listens for requests and responds.  That makes the sender and
** responder apps symmetric, the only difference being the IP address.
**
** The app that starts sending first is started by a kbhit().
**
** Right now we just send packets at some rate, probably much faster than
** the serial link can handle.  After the rest of the benchmark is working,
** we'll throttle the whole thing by having this app wait for replies
** before sending another request.
**
** Right now a problem with this code is the endian issue.  This code is
** written to run on a little endian 186, and the structures are all built as
** with little endian storage.  This data is transmitted accross a test network.
** and received by another procssor with identical little endian code.  So this
** is not an issue with our little test environment, but if we ever expect a
** real TCP/IP client to talk to us, we need to fix this.
**
**  Also we zero out the checksums for right now.
*/	
	PostLEDs(0);

//
// Danger!
//
// I build a fake MAC address here.  You really need to put in a valid 
// address.  If you don't have a EEPROM, this needs to be input at some
// time and stored in FLASH, (or input by the user every time).	
	
	for (i=0;i<6;i++) ppcnInit.eAddr[i] = i;  // was i

	PrintLCD("Waking up PCnetISA");

	if(ip_esrm()) exit(1);				// wake up the PCnetISA first.
    PrintLCD("Initializing PCnetISA");
    stat = (int)pcnInit(0, &ppcnInit);
		
	printf("pcnInit: status = %d\n",stat);
    
 // initialize the ICMP Echo Request Packet
 // do this in a top down fashion
	
	InitPacket();

	printf("Listening for ICMP echo request packets\n");
	t = 0;
	t1 = 0;
	r = 0;
	r1 = 0;
	sending = 0;  					  // default to just listening
	reply_recvd = 1;  
	noack = 1;
	txlen = sizeof(struct EPACKET);   // start up with max sized packets



//loop forever, checking for receive packets, and transmitting 
//echo requests if the user has hit a key

	while (1)
	{

 //if the user hits a 'G', start sending echo requests, a 'S' stops it.
		if(kbhit())
		{
			switch(getch())
			{
			case 'G':		// a 'G' means GO
			case 'g':
				printf("Go\n");
				sending = 1;
				reply_recvd = 1;
				noack =0;
				break;
			case 'S':		// S means STOP
			case 's':
				printf("Stop\n");
				sending = 0;
				noack = 0;
				break;
			case 'U':		// unacknowledged mode: don't wait for a reply before sending next packet
			case 'u':	
				printf("Unacknowledged Go\n");
				noack = sending = reply_recvd = 1;
				break;
			case 'M':
			case 'm':
				printf("Max Packet Size (1500 Bytes)\n");
				txlen = sizeof(struct EPACKET);  // max sized packets
				break;
			case 'Q':
			case 'q':
				return;	    // terminate program
				break;
			case '1':       // 64 byte packets
				printf("Min Packet Size (64 Bytes)\n");
				txlen = 64;
				break;
			case '2':	    // 200 bytes
				printf("200 Byte Packet Size\n");
				txlen = 200;
				break;
			case '5':	     // 500 bytes
				printf("500 Byte Packet Size\n");
				txlen = 500; 
				break;
			default:
				break;
			}
		}
		if(sending&&reply_recvd)		// do we need to transmit?
		{
//			printf("\nPacket Transmitted.\n");
			
			if(!noack) reply_recvd = 0; 
				stat = pcnOutput(0, (char *) &packet, txlen);	// output a packet
			if(((t>>2)<<2)==t++)		// increment the LEDs to indicate activity
			{
				PostLEDs((char)(((t1++)<<4)|(r1&0xf)));
				if(t1>=16) t1=0;
			}
		}
      
        rxlen = 0;
		
		if(pcnRProcess(0, PCN_MAX_RX_SIZE, rbuffer, &rxlen) == AMERROR_FRAME)
		{

// we just got a receive packet
// decide if this is a request or reply

			if(((r>>2)<<2)==r++)	// increment the LEDs to indicate activity
			{
				PostLEDs((char)(((t1)<<4)|(r1++&0xf)));
				if(r1>=16) r1=0;
			}
			pptr = (struct EPACKET *)rbuffer;
			
			echo_packet(pptr);  	// echo contents of receive data
			
			switch(pptr->ich.type)	// check the received packet type
			{
			case 0:	  				// reply, reset the flag
				reply_recvd = 1;
				break;
			case 8:   				// request, build a reply
				pptr->ich.type = 0;
				
				stat = pcnOutput(0, (char *) rbuffer, rxlen);
		
//				printf("\nPacket Transmitted.\n");
				
				if(((t>>2)<<2)==t++)
				{
					PostLEDs((char)(((t1++)<<4)|(r1&0xf)));
					if(t1>=16) t1=0;
				}
				break;
			default:
				printf("Invalid receive packet: ");
				for (i=0;i<10;i++) printf ("%02x ",rbuffer[i]);
				printf("\n");
				break;
			}		
		}
    }
	exit(0);
}

/*********************************************************************

 demo_desc - Prints out brief description of demo

  Prints out receive packet host&receive address and
  the first ten bytes of the data contents.

RETURNS:
	 	nothing.
 *********************************************************************/
void demo_desc(void)
{
	printf("\fEthernet Driver Demo...\n");
	printf("Make sure loopback plug is in CDP ethernet connector.\n");
	printf("Press any key to start.\n\n");
	while(!kbhit());
	getch();
}


/*********************************************************************

 echo_packet - Prints out receive packet contents

  Prints out receive packet host&receive address and
  the first ten bytes of the data contents.

RETURNS:
	 	nothing.
 *********************************************************************/
void echo_packet(struct EPACKET *pptr)
{
int i;
	
	printf("\nHost Address: ");
	for(i=0; i < 6 ; i++)
		printf("%x ",pptr->enh.source[i]);

	printf("\nReceive Address: ");
	for(i=0; i < 6 ; i++)
		printf("%x ",pptr->enh.dest[i]);
	
	printf("\nData: ");
	for(i=0; i < 10 ; i++)
	printf("%x ",pptr->data[i]);
	printf("\n\n");
}

/*********************************************************************

 InitPacket - initialization routine for network packets

  initializes the ICMP Echo Request Packet
  do this in a top down fashion

RETURNS:
	 	nothing.
 *********************************************************************/
void InitPacket()
{
int i;
//	pptr = (struct packet *) tbuffer;
	for (i=0;i<MAX_DATA;i++) packet.data[i] = i+6;

// now fill in the ICMP fields
	packet.ich.type = 8;			// icmp echo request
	packet.ich.code = 0;	
	packet.ich.checksum = 0;		// we fill in a bogus value, since it isn't checked
	packet.ich.identifier = 0x1234;	// just pick some value
	packet.ich.seqn = 0;	

// fill in the IP fields
	packet.iph.VI = 0x45;			// ipV4 packet 
	packet.iph.TOS = 0;
	packet.iph.length = sizeof(struct IP_HEADER)+sizeof(struct ICMP_HEADER)+MAX_DATA;
	packet.iph.identification = 0;
	packet.iph.frag_offset = 0;
	packet.iph.ttl = 0;
	packet.iph.protocol = 8;		// icmp echo request
	packet.iph.checksum = 0;		// we fill in a bogus value, since it isn't checked
	for (i=0;i<4;i++) packet.iph.source = my_ip_address;
	for (i=0;i<4;i++) packet.iph.dest = my_ip_address; //their_ip_address; 

// fill in the ethernet fields
	packet.enh.type = 0x8000;		// IP packet
	for (i=0;i<6;i++) packet.enh.dest[i] =  i; // was 0xff
	for (i=0;i<6;i++) packet.enh.source[i] = i; // was i
	return;
}

/*********************************************************************

 InitBoard - initializes CDP for ethernet controller

  performs configuration of 186CC resources depending on the usage of those
  resources for the given board.
  This routine sets PIOs and Chip Select registers for the 186CC 
  Customer Development Platform.

RETURNS:
		nothing.
*********************************************************************/
void InitBoard(unsigned int refresh)
{
	int temp;

	

//  Before we do anything, ensure that I/O is set to 16 bit mode.

	temp = _inpw(MPCS)&0xffef;		// set to 16 bit I/O
	_outp(MPCS,	temp);
	_outpw(MPCS,temp);

// first set the PIOs to allow the signals we need to have normal operation
// right now, these are MCS0, PCS1, PCS4, and PCS5.
// In addition, PIO27 (TMRIN0 should be set to an input with pull-up to allow the timer to count

#ifdef DRAM
#ifdef MCS3
	_outpw(PIOMODE0,_inpw(PIOMODE0)&~(0x2000|0x20|8|4));	//   Set these pins to normal operation
	_outpw(PIODIR0,_inpw(PIODIR0)&~(0x2000|0x20|8|4));		//   Set these pins to normal operation
#else
	_outpw(PIOMODE0,_inpw(PIOMODE0)&~(0x2000|0x10|8|4));	//   Set these pins to normal operation
	_outpw(PIODIR0,_inpw(PIODIR0)&~(0x2000|0x10|8|4));		//   Set these pins to normal operation
#endif
#else
	printf("Not Dram or MSC3");
	_outpw(PIOMODE0,_inpw(PIOMODE0)&~(0x2000|8|4));			//   Set these pins to normal operation
	_outpw(PIODIR0,_inpw(PIODIR0)&~(0x2000|8|4));			//   Set these pins to normal operation
#endif


//  For some reason, PIO34, which is also BHE*, was being set to a PIO input
// with termination.  This was actually the default, perhaps due to the PIO
// default race errata, but EMON was also writing the register to this setting.
// We need BHE* for the PCnetISA to work properly, so we set it to normal operation
// by clearing bit 2 in both the PIODIR2 and PIOMODE2 registers.

	_outpw(PIOMODE2,_inpw(PIOMODE2)&~(4));		//   Set these pins to normal operation
	_outpw(PIODIR2,_inpw(PIODIR2)&~(4));		//   Set these pins to normal operation

	_outpw(T0CON,TCON_INH);	//disable the timer

//set TMRIN0 to be an input with pullup to allow timer 0 to run
	_outpw(PIOMODE1,_inpw(PIOMODE1)&~(0x800));	//   Set these pins to normal operation
	_outpw(PIODIR1,_inpw(PIODIR1)|(0x800));	//   Set these pins to normal operation

#ifdef DRAM
	_outpw(UMCS,  (_inpw(UMCS)&0x8fff)|0x4000);	// move UCS lower boundary to C0000
	
#ifdef MCS3
	_outpw(MMCS,  0x81dc);						// set MCS for 80000,  0 wait states
#else
	_outpw(MMCS,  0x81fc);						// set MCS for 80000, MCSO only, 0 wait states
#endif
#endif
#ifdef MCS3
	_outpw(MPCS,  (_inpw(MPCS)&0x80ff)|0x2000);	// set MCS for 256K block
#else
	_outpw(MPCS,  (_inpw(MPCS)&0x80ff)|0x0800);	// set MCS for 64K block 
#endif

	_outpw(PACS,  _inpw(PACS)|0x0077);          // set PACS for three wait states, no external ready

}

