/******************************************************************************
 *                                                                            *
 * Copyright 1997 Advanced Micro Devices, Inc.                                *
 *                                                                            *
 * This software is the property of Advanced Micro Devices, Inc  (AMD)  which *
 * specifically  grants the user the right to modify, use and distribute this *
 * software provided this notice is not removed or altered.  All other rights *
 * are reserved by AMD.                                                       *
 *                                                                            *
 * AMD MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH REGARD TO THIS *
 * SOFTWARE.  IN NO EVENT SHALL AMD BE LIABLE FOR INCIDENTAL OR CONSEQUENTIAL *
 * DAMAGES IN CONNECTION WITH OR ARISING FROM THE FURNISHING, PERFORMANCE, OR *
 * USE OF THIS SOFTWARE.                                                      *
 *                                                                            *
 * So that all may benefit from your experience, please report  any  problems *
 * or suggestions about this software back to AMD.  Please include your name, *
 * company,  telephone number,  AMD product requiring support and question or *
 * problem encountered.                                                       *
 *                                                                            *
 * Advanced Micro Devices, Inc.       Worldwide support and contact           *
 * Logic Products Division            information available at:               *
 * Systems Engineering                                                        *
 * 5204 E. Ben White Blvd.     http://www.amd.com/html/support/techsup.html   *
 * Austin, TX 78741                                                           *
 *****************************************************************************/

/*
 pcndrv.h - PCI/PCNet driver structures.

	This contains all the basic structures used
	by the pcndrv.c driver.  It does not contain
	any of the physical hardware interface.
	That is found in pcn.h.

*/

#include "amdrive.h"
#include "pcn.h"

/*
** This structure is filled by the calling program before
** calling pcnInit().
*/

typedef struct PcnInit_s {
//	void	*configLocal;		/* Configuration space - local addr */
//	void	*rmapLocal;		/* Resource map - local address */
//	void	*rmapPci;		/* Resource map - PCI address */
        int	ioport;		/* I/O port */

	int	useBurned;		/* TRUE = use burned in address */
	U8	eAddr[6];		/* Ethernet address if useBurned==0 */
	int	*pcn_sig;		/* Pointer to the signal to use */
} PcnInit_s;

typedef struct PcnInfo_s {
	/*
	** Buffers for receiving and transmitting and local
	** descriptors.
	*/
	PcnRxDesc_s	rxDesc [ PCN_MAX_RX ];
	PcnTxDesc_s	txDesc [ PCN_MAX_TX ];
	U8		rxBuff [ PCN_MAX_RX ] [ PCN_MAX_RX_SIZE];
	U8		txBuff [ PCN_MAX_TX ] [ PCN_MAX_TX_SIZE];

    int		ioport;		/* I/O port */

	int		nextRx;		/* Next RX descriptor to get data */
	int		nextTx;		/* Next TX descriptor to use */
	int		readTx;		/* Last TX actually sent */


	U8		address[6];	/* Our ethernet address */

} PcnInfo_s;

/* Prototypes */
AMERROR pcnInit(int unitNumber, PcnInit_s *ppcnInit);
AMERROR pcnOutput(int unitNumber, U8 *txBuff, int length);
AMERROR pcnRProcess(int unitNumber, int buffLength, U8 *rxBuff, int *prxLength);
AMERROR xLenConv(int max_nX, int *xlen);
AMERROR pcnDump(int unitNumber);
AMERROR pcnShutdown(int unitNumber);

