/******************************************************************************
 *                                                                            *
 *     HDLC.H                                                                 *
 *                                                                            *
 *     This file contains hardware-specific declarations for                  *
 *     the 82525 HSCS on the ISDN daughter card.                              *
 *                                                                            *
 *                                                                            *
 ******************************************************************************
 *                                                                            *
 * Copyright 1996 Advanced Micro Devices, Inc.                                *
 *                                                                            *
 * This software is the property of Advanced Micro Devices, Inc  (AMD)  which *
 * specifically  grants the user the right to modify, use and distribute this *
 * software provided this notice is not removed or altered.  All other rights *
 * are reserved by AMD.                                                       *
 *                                                                            *
 * AMD MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH REGARD TO THIS *
 * SOFTWARE.  IN NO EVENT SHALL AMD BE LIABLE FOR INCIDENTAL OR CONSEQUENTIAL *
 * DAMAGES IN CONNECTION WITH OR ARISING FROM THE FURNISHING, PERFORMANCE, OR *
 * USE OF THIS SOFTWARE.                                                      *
 *                                                                            *
 * So that all may benefit from your experience, please report  any  problems *
 * or suggestions about this software back to AMD.  Please include your name, *
 * company,  telephone number,  AMD product requiring support and question or *
 * problem encountered.                                                       *
 *                                                                            *
 * Advanced Micro Devices, Inc.       Worldwide support and contact           *
 * Logic Products Division            information available at:               *
 * Systems Engineering                                                        *
 * 5204 E. Ben White Blvd.     http://www.amd.com/html/support/techsup.html   *
 * Austin, TX 78741                                                           *
 *****************************************************************************/
#ifndef _HDLC_H_
#define _HDLC_H_
// =====================================================================
// 
//
// the HSCX is on PCS0
//
// Chip select registers
//
#define CS_HDLCA       0x00         // PCS 0 is at I/O addr 0
#define CS_HDLCB       0x80         // Channel B is at 40*2
//


// On the daughter card, MA1 from the 186 is connected
// to A0 on the HSCX.  This means that the I/O to the
// HSCX happens on even addresses only.

// HCSX register offset definitions

#define OFFS_FIFO       0x00         // TX and RX fifos at 0-3E
#define OFFS_ISTA       0x40         // interrupt status (read)
#define OFFS_MASK       0x40         // interrupt mask (write)
#define OFFS_STAR       0x42         // status (read)
#define OFFS_CMDR       0x42         // command (write)

#define OFFS_MODE       0x44         // interrupt status (read/write)
#define OFFS_TIMR       0x46         // timer (read/write)

#define OFFS_EXIR       0x48         // extended interrupt (read)
#define OFFS_XAD1       0x48         // transmit address 1 (write)
#define OFFS_RBCL       0x4A         // receive byte count low (read)
#define OFFS_XAD2       0x4A         // transmit address 2 (write)

#define OFFS_RAH1       0x4C         // receive address high 1  (write)
#define OFFS_RSTA       0x4E         // receive status (read)
#define OFFS_RAH2       0x50         // receive address high 2 (write)
#define OFFS_RAL1       0x50         // receive address low 1  (read/write)
#define OFFS_RHCR       0x52         // receive HDLC control (read)
#define OFFS_RAL2       0x52         // receive address low 2 (write)

#define OFFS_XBCL       0x54         // transmit byte count low (write)
#define OFFS_BGR        0x56         // baudrate generator (write)
#define OFFS_CCR2       0x58         // channel config 2 (read/write)
#define OFFS_RBCH       0x5A         // receive byte count high (read)
#define OFFS_XBCH       0x5A         // receive byte count high (write)
#define OFFS_VSTR       0x5C         // version status (read)
#define OFFS_RLCR       0x5C         // receive frame length check (write)
#define OFFS_CCR1       0x5E         // channel config 1 (read/write)
#define OFFS_TSAX       0x60         // time slot assignment transmit (write)
#define OFFS_TSAR       0x62         // time slot assignment receive (write)
#define OFFS_XCCR       0x64         // transmit channel capacity (write)
#define OFFS_RCCR       0x66         // receive channel capacityt (write)

// Miscellaneous control registers
//
#define FIFO_REG       (CS_HDLCA+OFFS_FIFO)         // TX and RX fifos at 0-3E
#define ISTA_REG       (CS_HDLCA+OFFS_ISTA)         // interrupt status (read)
#define MASK_REG       (CS_HDLCA+OFFS_MASK)         // interrupt mask (write)
#define STAR_REG       (CS_HDLCA+OFFS_STAR)         // status (read)
#define CMDR_REG       (CS_HDLCA+OFFS_CMDR)         // command (write)

#define MODE_REG       (CS_HDLCA+OFFS_MODE)         // interrupt status (read/write)
#define TIMR_REG       (CS_HDLCA+OFFS_TIMR)         // timer (read/write)

#define EXIR_REG       (CS_HDLCA+OFFS_EXIR)         // extended interrupt (read)
#define XAD1_REG       (CS_HDLCA+OFFS_XAD1)         // transmit address 1 (write)
#define RBCL_REG       (CS_HDLCA+OFFS_RBCL)         // receive byte count low (read)
#define XAD2_REG       (CS_HDLCA+OFFS_XAD2)         // transmit address 2 (write)

#define RAH1_REG       (CS_HDLCA+OFFS_RAH1)         // receive address high 1  (write)
#define RSTA_REG       (CS_HDLCA+OFFS_RSTA)         // receive status (read)
#define RAH2_REG       (CS_HDLCA+OFFS_RAH2)         // receive address high 2 (write)
#define RAL1_REG       (CS_HDLCA+OFFS_RAL1)         // receive address low 1  (read/write)
#define RHCR_REG       (CS_HDLCA+OFFS_RHCR)         // receive HDLC control (read)
#define RAL2_REG       (CS_HDLCA+OFFS_RAL2)         // receive address low 2 (write)

#define XBCL_REG       (CS_HDLCA+OFFS_XBCL)         // transmit byte count low (write)
#define BGR_REG        (CS_HDLCA+OFFS_BGR)          // baudrate generator (write)
#define CCR2_REG       (CS_HDLCA+OFFS_CCR2)         // channel config 2 (read/write)
#define RBCH_REG       (CS_HDLCA+OFFS_RBCH)         // receive byte count high (read)
#define XBCH_REG       (CS_HDLCA+OFFS_XBCH)         // receive byte count high (write)
#define VSTR_REG       (CS_HDLCA+OFFS_VSTR)         // status (read)
#define RLCR_REG       (CS_HDLCA+OFFS_RLCR)         // command (write)
#define CCR1_REG       (CS_HDLCA+OFFS_CCR1)         // channel config 1 (read/write)
#define TSAX_REG       (CS_HDLCA+OFFS_TSAX)         // time slot assignment transmit (write)
#define TSAR_REG       (CS_HDLCA+OFFS_TSAR)         // time slot assignment receive (write)
#define XCCR_REG       (CS_HDLCA+OFFS_XCCR)         // transmit channel capacity (write)
#define RCCR_REG       (CS_HDLCA+OFFS_RCCR)         // receive channel capacityt (write)
//

// =======================================================================
// Internal Register field definitions

//

#endif
